/*
 *  swimacpdsm.h
 *  swimac
 *
 *  Created by Jerry Pickering on 1/17/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 *		Location Based Services (GPS) APIS
 */

#ifndef __SWIMACPDSM_H__
#define __SWIMACPDSM_H__

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacrcodes.h"
#import "swimacdatatypes.h"
#import "swimacstructs.h"

#pragma mark
#pragma mark --Location Based Services (GPS)--
#pragma mark
//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetPdsmLocNotifyStatus - Check notification status
//
// Purpose:	This function check the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PD_DONE
//				CNS_PDSM_PD_DATA
//				CNS_PDSM_PD_END
//				CNS_PDSM_PD_BEGIN
//				CNS_PDSM_PD_UPDATE_FAILURE
//				
// Parameters:  
//			psNotifyStatus[OUT]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmLocNotifyStatus(SWI_STRUCT_PDSMLocNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetPdsmLocNotifyStatus - Set the notification status
//
// Purpose:	This function sets the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PD_DONE
//				CNS_PDSM_PD_DATA
//				CNS_PDSM_PD_END
//				CNS_PDSM_PD_BEGIN
//				CNS_PDSM_PD_UPDATE_FAILURE
//				
// Parameters:  
//			psNotifyStatus[IN]	Set notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmLocNotifyStatus(SWI_STRUCT_PDSMLocNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetPdsmDloadNotifyStatus - Check notification status
//
// Purpose:	This function check the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PD_DLOAD_BEGIN 
//				CNS_PDSM_PD_DLOAD
//				CNS_PDSM_PD_DLOAD_END
//				CNS_PDSM_PD_DLOAD_DONE
//				
// Parameters:  
//			psNotifyStatus[OUT]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmDloadNotifyStatus(SWI_STRUCT_PDSMDloadNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetPdsmDloadNotifyStatus - Sets the notification status
//
// Purpose:	This function check the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PD_DLOAD_BEGIN 
//				CNS_PDSM_PD_DLOAD
//				CNS_PDSM_PD_DLOAD_END
//				CNS_PDSM_PD_DLOAD_DONE
//				
// Parameters:  
//			psNotifyStatus[IN]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmDloadNotifyStatus(SWI_STRUCT_PDSMDloadNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetPdsmParamNotifyStatus - Check notification status
//
// Purpose:	This function check the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PA_IP_ADDR 
//				CNS_PDSM_PA_GPS_LOCK  
//				CNS_PDSM_PA_PTLM_MODE 
//				CNS_PDSM_PA_PORT_ID 
//				CNS_PDSM_PA_PRIVACY 
//				CNS_PDSM_PA_NET_ACCESS 
//				
// Parameters:  
//			psNotifyStatus[OUT]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmParamNotifyStatus(SWI_STRUCT_PDSMParamNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetPdsmParamNotifyStatus - Sets the notification status
//
// Purpose:	This function sets the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PA_IP_ADDR 
//				CNS_PDSM_PA_GPS_LOCK  
//				CNS_PDSM_PA_PTLM_MODE 
//				CNS_PDSM_PA_PORT_ID 
//				CNS_PDSM_PA_PRIVACY 
//				CNS_PDSM_PA_NET_ACCESS 
//				
// Parameters:  
//			psNotifyStatus[IN]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmParamNotifyStatus(SWI_STRUCT_PDSMParamNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetPdsmPdDownload - Request a data 
//
// Purpose:	This function will be used to requests a data download of ephemeris 
//			and almanac data.
//				
// Parameters:  
//			sPdsmPdDownload[IN]	Input vatiable for data download request check 
//								out SWI_STRUCT_PDSM_PD_Download structure for details 
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPdDownload(const SWI_STRUCT_PDSM_PD_Download *psPdsmPdDownload, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPdGetPos - Requests a single location fix
//
// Purpose:     This function will be used to Requests a single location fix.
//				
// Parameters:  
//            SWI_STRUCT_PDSM_PD_GetPosSpeed[In]      Is of type SWI_STRUCT_PDSM_PD_GetPosSpeed structure and contains Pos speed information..
//            timeout[IN]        Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPdGetPos(const SWI_STRUCT_PDSM_PD_GetPos *psPdsmPdGetPos, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPdStatus - Get current status of the PDSM.
//
// Purpose:     This function requests that the modem provide the current status 
//				of the PDSM.
//				
// Parameters:  
//            psPdsmPdGetStatus[In]	Contains current status of the PDSM.
//            timeout[IN]			Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPdStatus(SWI_STRUCT_PDSM_PD_GetStatus *psPdsmPdGetStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPdTrack - Start a tracking session
//
// Purpose:     This function requests that the modem start a tracking session.
//				
// Parameters:  
//            sPdsmPdTrack[IN]	Input vatiable for tracking 
//            check out SWI_STRUCT_PDSM_PD_Track structure for details 
//            timeout[IN]		Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		This API will check if SWI_NOTIFY_GPSTrackingGroup is enabled before starting 
//          the tracking session. If not enabled then it should return error. The API doesn't 
//          filter anything else besides this check.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPdTrack(const SWI_STRUCT_PDSM_PD_Track *psPdsmPdTrack, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPdEndSession - Ends current LBS tracking session
//
// Purpose:     This function will be used to stop tracking.
//				
// Parameters:  
//				psPdsmPdEndSession[IN]	Input vatiable specifying Session type 
//				check out SWI_STRUCT_PDSM_PD_EndSession structure for details 
//				timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		This API will respond with a CNS_PDSM_PD_END/CNS_PDSM_PD_DONE notification 
//          that includes the End status. See Table 2-PDErrType on memo017-14
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPdEndSession(const SWI_STRUCT_PDSM_PD_EndSession *psPdsmPdEndSession, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPaParam - Get default setting from modem.
//
// Purpose:     This function requests the modem's default parameter settings.
//				
// Parameters:  
//            stPAParam[OUT]     Is of type SWI_STRUCT_PDSM_PA_GetParam contains result.
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	This API just passes down to the modem wihtout any extra filtering. The response 
//        payload of this object contains the current setting. No notification will be generated.		
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPaParam(SWI_STRUCT_PDSM_PA_GetParam *psPdsmPdGetParam, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPdData - Get the results of the position fix.
//
// Purpose:     This function gets the results of the position fix.
//				
// Parameters:  
//            psPdsmPdData[OUT]	Contains result.
//            timeout[IN]       Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	This API just passes down to the modem wihtout any extra filtering. The response 
//        payload of this object contains the current setting. No notification will be generated.		
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPdData(SWI_STRUCT_PDSM_PD_Data *psPdsmPdData, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPaIpAddr - Get GPS IP Address from modem.
//
// Purpose:     This function will be used to get GPS IP Address settings from the modem.
//				
// Parameters:  
//            stPAIPAddr[OUT]     Is of type SWI_STRUCT_PDSM_PA_IP_Addr contains result.
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	The PDE IP Address is a write only field and is not to be displayed to users.  This API will
//        return:
//        0.0.0.0         : the IP address is 0.0.0.0 or PDE NV Item is inactive (GPS not supported)
//        255.255.255.255 : the device has valid PDE IP address. 
//        IP Address      : the device is internally unlocked and will return the true address
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPaIpAddr(SWI_STRUCT_PDSM_PA_IP_Addr *stPAIPAddr, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPaIpAddr - Set GPS IP Address.
//
// Purpose:     This function will be used to set current GPS IP Address 
//				
// Parameters:  
//            stPAIPAddr[IN]      Is of type SWI_STRUCT_PDSM_PA_IP_Addr structure and  contains IP address to be set.
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPaIpAddr(const SWI_STRUCT_PDSM_PA_IP_Addr *psPAIPAddr, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetGPSLockSetting - Set GPS Lock Setting.
//
// Purpose:     This function will be used to get GPS Lock Setting settings from the modem.
//				
// Parameters:  
//            stPAGPSLock[OUT]    Is of type SWI_STRUCT_PDSM_PA_Gps_Lock structure and  contains result..
//            timeout[IN]         Function timeout in milliseconds
//            see enum SWI_PDSM_GpsLock for all lock values
// Return:      See SwiRcodes.h
//
// Notes:	
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPaGpsLock(SWI_STRUCT_PDSM_PA_Gps_Lock *stPAGPSLock, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPaGpsLock - Set GPS Lock Setting
//
// Purpose:     This function will be used to set GPS Lock Setting.
//				
// Parameters:  
//            stPAGPSLock[IN]      Is of type SWI_STRUCT_PDSM_PA_Gps_Lock structure and  contains GPS LOCK to be set.
//            see enum SWI_PDSM_GpsLock for all lock values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPaGpsLock(const SWI_STRUCT_PDSM_PA_Gps_Lock *psPAGPSLock, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPaPtlmMode - Get GPS PTLM Mode Setting
//
// Purpose:     This function will be used to get GPS PTLM mode setting from the modem.
//				
// Parameters:  
//            stPAPTLMMode[OUT]     Is of type SWI_STRUCT_PDSM_PA_PTLM_Mode structure and  contains result..
//            see enum SWI_PDSM_DP_TransportMech for all PTLM  values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPaPtlmMode(SWI_STRUCT_PDSM_PA_PTLM_Mode *stPAPTLMMode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPaPtlmMode - Set GPS PTLM Mode Setting.
//
// Purpose:     This function will be used to set GPS PTLM mode setting
//				
// Parameters:  
//            stPAPTLMMode[IN]      Is of type SWI_STRUCT_PDSM_PA_PTLM_Mode structure and  contains PTLM Mode (Transport Mechanism Values) to be set.
//            see enum SWI_PDSM_DP_TransportMech for all PTLM  values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPaPtlmMode(const SWI_STRUCT_PDSM_PA_PTLM_Mode *psPAPTLMMode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPaPortId - Get GPS PortID Setting.
//
// Purpose:     This function will be used to get GPS PortID setting from the modem.
//				
// Parameters:  
//            stPAPortID[OUT]     Is of type SWI_STRUCT_PDSM_PA_Port_ID structure and  contains result..
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPaPortId(SWI_STRUCT_PDSM_PA_Port_ID *stPAPortID, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPaPortId - Set GPS PortID Setting.
//
// Purpose:     This function will be used to set GPS PortID Setting
//				
// Parameters:  
//            stPAPortID[IN]      Is of type  SWI_STRUCT_PDSM_PA_Port_ID structure and  contains PortID to be set.
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPaPortId(const SWI_STRUCT_PDSM_PA_Port_ID *psPAPortID, SWI_U32 timeout);

// Legacy/backword compatible call to SwiSetPdsmPaPortId()
SWI_RCODE SwiSetPdsmPaortId(const SWI_STRUCT_PDSM_PA_Port_ID *psPAPortID, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPaPrivacy - Get GPS Privacy Setting.
//
// Purpose:     This function will be used to get GPS Privacy Setting from the modem.
//				
// Parameters:  
//            stPAPrivacy[OUT]     Is of type SWI_STRUCT_PDSM_PA_Privacy structure and contains result.
//            see enum SWI_PDSM_Privacy for all Pricacy values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPaPrivacy(SWI_STRUCT_PDSM_PA_Privacy *stPAPrivacy, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPaPrivacy - Set GPS Privacy Setting.
//
// Purpose:     This function will be used to set GPS Privacy Setting.
//				
// Parameters:  
//            stPAPrivacy[IN]     Is of type SWI_STRUCT_PDSM_PA_Privacy structure and  contains GPS privacy to be set.
//            see enum SWI_PDSM_Privacy for all Pricacy values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPaPrivacy(const SWI_STRUCT_PDSM_PA_Privacy *psPAPrivacy, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPaNetAccess - Get GPS NetAccess Setting
//
// Purpose:     This function will be used to get GPS NetAccess Setting from the modem.
//				
// Parameters:  
//            stPANetAccess[OUT]  IIs of type SWI_STRUCT_PDSM_PA_Net_Access structure and contains result.
//            see enum SWI_PDSM_PA_NetAccess for all Net Access values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPaNetAccess(SWI_STRUCT_PDSM_PA_Net_Access *stPANetAccess, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmPaNetAccess - Set GPS NetAccess Setting
//
// Purpose:     This function will be used to set GPS NetAccess setting
//				
// Parameters:  
//            stPANetAccess[IN]   Is of type SWI_STRUCT_PDSM_PA_Net_Access structure and contains Net Access to be set..
//            see enum SWI_PDSM_PA_NetAccess for all Net Access values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPdsmPaNetAccess(const SWI_STRUCT_PDSM_PA_Net_Access *psPANetAccess, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPaBsInfo - Get GPS BS Info.
//
// Purpose:     This function will be used to get GPS BS Information.
//				
// Parameters:  
//            stBSInfo[OUT]      Is of type SWI_STRUCT_PDSM_PA_BS_Info structure and contains base station information..
//            timeout[IN]        Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	This API is very similar to SwiGetTechBSInfo
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmPaBsInfo(SWI_STRUCT_PDSM_PA_BS_Info *stBSInfo, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmSATInfo - Get GPS SAT Info.
//
// Purpose:     This function will be used to get GPS SAT Information.
//				
// Parameters:  
//            stSATInfo[OUT]      Is of type SWI_STRUCT_PDSM_SAT_Info structure and contains base station information..
//            timeout[IN]        Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	This API is very similar to SwiGetTechBSInfo
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPdsmSATInfo(SWI_STRUCT_PDSM_SAT_Info *stSATInfo, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPdsmClearAssistance - Start a tracking session
//
// Purpose:     This function requests that the modem clear various location parameters to simulate a cold start.
//				
// Parameters:  
//            sPdsmPdTrack[IN]	Input variable for clearing location parameters
//            check out SWI_STRUCT_PDSM_CLEAR_ASSISTANCE structure for details 
//            timeout[IN]		Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		
//
//////////////////////////////////////////////////////////////////////////////////

SWI_RCODE SwiSetPdsmClearAssistance(const SWI_STRUCT_PDSM_CLEAR_ASSISTANCE *psPdsmClearAssistance, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name: SwiGetLbsFixTypeSupportStatus 
//
// Purpose: Get the device's General Feature support capabilities. 
//
// Parameters:  pStatus[OUT]		contains a total of 6 bytes where each byte can 
//									be set to either Enable (1) or Disable (0).  
//									The six bytes represent control for the following 
//									fix types in this order:
//									0: Autonomous(Standalone Mode)
//									1: MS-Based Mode
//									2: MS-Assisted Mode
//									3: Optimal Accuracy Mode
//									4: Optimal Speed Mode
//									5: Optimal Data Mode
//				nLen[IN]			Length of the buffer that pStatus points
//              timeout[IN]			Api timeout
//
// Return:      See SwiRcodes.h
//              
// Notes:   This functionality is not support on all devices.  A successful return indicates the
//          functionality exists and the LED setting was set.  To determine if feature is supported,
//          use SwiGetLEDEnable().
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsFixTypeSupportStatus( SWI_U8 *pStatus, SWI_U32 nLen, SWI_U32 timeout );
	


//**********************************************************************************
//	SwiGetPDSMData
//		This call returns all the GPS data in one structure
//		the primary use is to check all the "GET" calls for
//		GPS
//**********************************************************************************
typedef struct allPDSMData
{
	SWI_RCODE							_ret[14];
	SWI_STRUCT_PDSMLocNotifyStatus		_locNotifyStatus;
	SWI_STRUCT_PDSMDloadNotifyStatus	_dloadNotifyStatus;
	SWI_STRUCT_PDSMParamNotifyStatus	_paramNotifyStatus;
	SWI_STRUCT_PDSM_PD_GetStatus		_pdGetStatus;
	SWI_STRUCT_PDSM_PA_GetParam			_paGetParam;
	SWI_STRUCT_PDSM_PD_Data				_pdData;
	SWI_STRUCT_PDSM_PA_IP_Addr			_paIPAddr;
	SWI_STRUCT_PDSM_PA_Gps_Lock			_paGpsLock;
	SWI_STRUCT_PDSM_PA_PTLM_Mode		_paPTLMMode;
	SWI_STRUCT_PDSM_PA_Port_ID			_paPortID;
	SWI_STRUCT_PDSM_PA_Privacy			_paPrivacy;
	SWI_STRUCT_PDSM_PA_Net_Access		_paNetAccess;
	SWI_STRUCT_PDSM_PA_BS_Info			_paBSInfo;
	SWI_STRUCT_PDSM_SAT_Info			_satInfo;
} allPDSMData;

SWI_RCODE SwiGetPDSMData(allPDSMData *data);



#pragma mark
#pragma mark --LBS Based Services (GPS)--
#pragma mark
//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetLbsLocNotifyStatus - Check notification status
//
// Purpose:	This function check the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PD_DONE
//				CNS_PDSM_PD_DATA
//				CNS_PDSM_PD_END
//				CNS_PDSM_PD_BEGIN
//				CNS_PDSM_PD_UPDATE_FAILURE
//				
// Parameters:  
//			psNotifyStatus[OUT]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsLocNotifyStatus(SWI_STRUCT_PDSMLocNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetLbsLocNotifyStatus - Set the notification status
//
// Purpose:	This function sets the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PD_DONE
//				CNS_PDSM_PD_DATA
//				CNS_PDSM_PD_END
//				CNS_PDSM_PD_BEGIN
//				CNS_PDSM_PD_UPDATE_FAILURE
//				
// Parameters:  
//			psNotifyStatus[IN]	Set notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsLocNotifyStatus(SWI_STRUCT_PDSMLocNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetLbsDloadNotifyStatus - Check notification status
//
// Purpose:	This function check the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PD_DLOAD_BEGIN 
//				CNS_PDSM_PD_DLOAD
//				CNS_PDSM_PD_DLOAD_END
//				CNS_PDSM_PD_DLOAD_DONE
//				
// Parameters:  
//			psNotifyStatus[OUT]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsDloadNotifyStatus(SWI_STRUCT_PDSMDloadNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetLbsDloadNotifyStatus - Sets the notification status
//
// Purpose:	This function check the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PD_DLOAD_BEGIN 
//				CNS_PDSM_PD_DLOAD
//				CNS_PDSM_PD_DLOAD_END
//				CNS_PDSM_PD_DLOAD_DONE
//				
// Parameters:  
//			psNotifyStatus[IN]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsDloadNotifyStatus(SWI_STRUCT_PDSMDloadNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetLbsParamNotifyStatus - Check notification status
//
// Purpose:	This function check the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PA_IP_ADDR 
//				CNS_PDSM_PA_GPS_LOCK  
//				CNS_PDSM_PA_PTLM_MODE 
//				CNS_PDSM_PA_PORT_ID 
//				CNS_PDSM_PA_PRIVACY 
//				CNS_PDSM_PA_NET_ACCESS 
//				
// Parameters:  
//			psNotifyStatus[OUT]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsParamNotifyStatus(SWI_STRUCT_PDSMParamNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetLbsParamNotifyStatus - Sets the notification status
//
// Purpose:	This function sets the current notification state of the following 
//			group of CnS notifications:
//
//				CNS_PDSM_PA_IP_ADDR 
//				CNS_PDSM_PA_GPS_LOCK  
//				CNS_PDSM_PA_PTLM_MODE 
//				CNS_PDSM_PA_PORT_ID 
//				CNS_PDSM_PA_PRIVACY 
//				CNS_PDSM_PA_NET_ACCESS 
//				
// Parameters:  
//			psNotifyStatus[IN]	Save current notification status data
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsParamNotifyStatus(SWI_STRUCT_PDSMParamNotifyStatus *psNotifyStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetLbsPdDownload - Request a data 
//
// Purpose:	This function will be used to requests a data download of ephemeris 
//			and almanac data.
//				
// Parameters:  
//			sPdsmPdDownload[IN]	Input vatiable for data download request check 
//								out SWI_STRUCT_PDSM_PD_Download structure for details 
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	See SwiRcodes.h
//
// Notes:	None.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPdDownload(const SWI_STRUCT_PDSM_PD_Download *psPdsmPdDownload, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPdGetPos - Requests a single location fix
//
// Purpose:     This function will be used to Requests a single location fix.
//				
// Parameters:  
//            SWI_STRUCT_PDSM_PD_GetPosSpeed[In]      Is of type SWI_STRUCT_PDSM_PD_GetPosSpeed structure and contains Pos speed information..
//            timeout[IN]        Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPdGetPos(const SWI_STRUCT_PDSM_PD_GetPos *psPdsmPdGetPos, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsPdStatus - Get current status of the PDSM.
//
// Purpose:     This function requests that the modem provide the current status 
//				of the PDSM.
//				
// Parameters:  
//            psPdsmPdGetStatus[In]	Contains current status of the PDSM.
//            timeout[IN]			Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPdStatus(SWI_STRUCT_PDSM_PD_GetStatus *psPdsmPdGetStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPdTrack - Start a tracking session
//
// Purpose:     This function requests that the modem start a tracking session.
//				
// Parameters:  
//            sPdsmPdTrack[IN]	Input vatiable for tracking 
//            check out SWI_STRUCT_PDSM_PD_Track structure for details 
//            timeout[IN]		Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		This API will check if SWI_NOTIFY_GPSTrackingGroup is enabled before starting 
//          the tracking session. If not enabled then it should return error. The API doesn't 
//          filter anything else besides this check.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPdTrack(const SWI_STRUCT_PDSM_PD_Track *psPdsmPdTrack, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPdEndSession - Ends current LBS tracking session
//
// Purpose:     This function will be used to stop tracking.
//				
// Parameters:  
//				psPdsmPdEndSession[IN]	Input vatiable specifying Session type 
//				check out SWI_STRUCT_PDSM_PD_EndSession structure for details 
//				timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		This API will respond with a CNS_PDSM_PD_END/CNS_PDSM_PD_DONE notification 
//          that includes the End status. See Table 2-PDErrType on memo017-14
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPdEndSession(const SWI_STRUCT_PDSM_PD_EndSession *psPdsmPdEndSession, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsPaParam - Get default setting from modem.
//
// Purpose:     This function requests the modem's default parameter settings.
//				
// Parameters:  
//            stPAParam[OUT]     Is of type SWI_STRUCT_PDSM_PA_GetParam contains result.
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	This API just passes down to the modem wihtout any extra filtering. The response 
//        payload of this object contains the current setting. No notification will be generated.		
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPaParam(SWI_STRUCT_PDSM_PA_GetParam *psPdsmPdGetParam, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsPdData - Get the results of the position fix.
//
// Purpose:     This function gets the results of the position fix.
//				
// Parameters:  
//            psPdsmPdData[OUT]	Contains result.
//            timeout[IN]       Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	This API just passes down to the modem wihtout any extra filtering. The response 
//        payload of this object contains the current setting. No notification will be generated.		
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPdData(SWI_STRUCT_PDSM_PD_Data *psPdsmPdData, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsPaIpAddr - Get GPS IP Address from modem.
//
// Purpose:     This function will be used to get GPS IP Address settings from the modem.
//				
// Parameters:  
//            stPAIPAddr[OUT]     Is of type SWI_STRUCT_PDSM_PA_IP_Addr contains result.
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	The PDE IP Address is a write only field and is not to be displayed to users.  This API will
//        return:
//        0.0.0.0         : the IP address is 0.0.0.0 or PDE NV Item is inactive (GPS not supported)
//        255.255.255.255 : the device has valid PDE IP address. 
//        IP Address      : the device is internally unlocked and will return the true address
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPaIpAddr(SWI_STRUCT_PDSM_PA_IP_Addr *stPAIPAddr, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPaIpAddr - Set GPS IP Address.
//
// Purpose:     This function will be used to set current GPS IP Address 
//				
// Parameters:  
//            stPAIPAddr[IN]      Is of type SWI_STRUCT_PDSM_PA_IP_Addr structure and  contains IP address to be set.
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPaIpAddr(const SWI_STRUCT_PDSM_PA_IP_Addr *psPAIPAddr, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetGPSLockSetting - Set GPS Lock Setting.
//
// Purpose:     This function will be used to get GPS Lock Setting settings from the modem.
//				
// Parameters:  
//            stPAGPSLock[OUT]    Is of type SWI_STRUCT_PDSM_PA_Gps_Lock structure and  contains result..
//            timeout[IN]         Function timeout in milliseconds
//            see enum SWI_PDSM_GpsLock for all lock values
// Return:      See SwiRcodes.h
//
// Notes:	
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPaGpsLock(SWI_STRUCT_PDSM_PA_Gps_Lock *stPAGPSLock, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPaGpsLock - Set GPS Lock Setting
//
// Purpose:     This function will be used to set GPS Lock Setting.
//				
// Parameters:  
//            stPAGPSLock[IN]      Is of type SWI_STRUCT_PDSM_PA_Gps_Lock structure and  contains GPS LOCK to be set.
//            see enum SWI_PDSM_GpsLock for all lock values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPaGpsLock(const SWI_STRUCT_PDSM_PA_Gps_Lock *psPAGPSLock, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsPaPtlmMode - Get GPS PTLM Mode Setting
//
// Purpose:     This function will be used to get GPS PTLM mode setting from the modem.
//				
// Parameters:  
//            stPAPTLMMode[OUT]     Is of type SWI_STRUCT_PDSM_PA_PTLM_Mode structure and  contains result..
//            see enum SWI_PDSM_DP_TransportMech for all PTLM  values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPaPtlmMode(SWI_STRUCT_PDSM_PA_PTLM_Mode *stPAPTLMMode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPaPtlmMode - Set GPS PTLM Mode Setting.
//
// Purpose:     This function will be used to set GPS PTLM mode setting
//				
// Parameters:  
//            stPAPTLMMode[IN]      Is of type SWI_STRUCT_PDSM_PA_PTLM_Mode structure and  contains PTLM Mode (Transport Mechanism Values) to be set.
//            see enum SWI_PDSM_DP_TransportMech for all PTLM  values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPaPtlmMode(const SWI_STRUCT_PDSM_PA_PTLM_Mode *psPAPTLMMode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsPaPortId - Get GPS PortID Setting.
//
// Purpose:     This function will be used to get GPS PortID setting from the modem.
//				
// Parameters:  
//            stPAPortID[OUT]     Is of type SWI_STRUCT_PDSM_PA_Port_ID structure and  contains result..
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPaPortId(SWI_STRUCT_PDSM_PA_Port_ID *stPAPortID, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPaPortId - Set GPS PortID Setting.
//
// Purpose:     This function will be used to set GPS PortID Setting
//				
// Parameters:  
//            stPAPortID[IN]      Is of type  SWI_STRUCT_PDSM_PA_Port_ID structure and  contains PortID to be set.
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPaPortId(const SWI_STRUCT_PDSM_PA_Port_ID *psPAPortID, SWI_U32 timeout);

// Legacy/backword compatible call to SwiSetLbsPaPortId()
SWI_RCODE SwiSetLbsPaortId(const SWI_STRUCT_PDSM_PA_Port_ID *psPAPortID, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPdsmPaPrivacy - Get GPS Privacy Setting.
//
// Purpose:     This function will be used to get GPS Privacy Setting from the modem.
//				
// Parameters:  
//            stPAPrivacy[OUT]     Is of type SWI_STRUCT_PDSM_PA_Privacy structure and contains result.
//            see enum SWI_PDSM_Privacy for all Pricacy values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPaPrivacy(SWI_STRUCT_PDSM_PA_Privacy *stPAPrivacy, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPaPrivacy - Set GPS Privacy Setting.
//
// Purpose:     This function will be used to set GPS Privacy Setting.
//				
// Parameters:  
//            stPAPrivacy[IN]     Is of type SWI_STRUCT_PDSM_PA_Privacy structure and  contains GPS privacy to be set.
//            see enum SWI_PDSM_Privacy for all Pricacy values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPaPrivacy(const SWI_STRUCT_PDSM_PA_Privacy *psPAPrivacy, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsPaNetAccess - Get GPS NetAccess Setting
//
// Purpose:     This function will be used to get GPS NetAccess Setting from the modem.
//				
// Parameters:  
//            stPANetAccess[OUT]  IIs of type SWI_STRUCT_PDSM_PA_Net_Access structure and contains result.
//            see enum SWI_PDSM_PA_NetAccess for all Net Access values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPaNetAccess(SWI_STRUCT_PDSM_PA_Net_Access *stPANetAccess, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsPaNetAccess - Set GPS NetAccess Setting
//
// Purpose:     This function will be used to set GPS NetAccess setting
//				
// Parameters:  
//            stPANetAccess[IN]   Is of type SWI_STRUCT_PDSM_PA_Net_Access structure and contains Net Access to be set..
//            see enum SWI_PDSM_PA_NetAccess for all Net Access values
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLbsPaNetAccess(const SWI_STRUCT_PDSM_PA_Net_Access *psPANetAccess, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsPaBsInfo - Get GPS BS Info.
//
// Purpose:     This function will be used to get GPS BS Information.
//				
// Parameters:  
//            stBSInfo[OUT]      Is of type SWI_STRUCT_PDSM_PA_BS_Info structure and contains base station information..
//            timeout[IN]        Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	This API is very similar to SwiGetTechBSInfo
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsPaBsInfo(SWI_STRUCT_PDSM_PA_BS_Info *stBSInfo, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLbsSATInfo - Get GPS SAT Info.
//
// Purpose:     This function will be used to get GPS SAT Information.
//				
// Parameters:  
//            stSATInfo[OUT]      Is of type SWI_STRUCT_PDSM_SAT_Info structure and contains base station information..
//            timeout[IN]        Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:	This API is very similar to SwiGetTechBSInfo
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLbsSATInfo(SWI_STRUCT_PDSM_SAT_Info *stSATInfo, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetLbsClearAssistance - Start a tracking session
//
// Purpose:     This function requests that the modem clear various location parameters to simulate a cold start.
//				
// Parameters:  
//            sPdsmPdTrack[IN]	Input variable for clearing location parameters
//            check out SWI_STRUCT_PDSM_CLEAR_ASSISTANCE structure for details 
//            timeout[IN]		Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		
//
//////////////////////////////////////////////////////////////////////////////////

SWI_RCODE SwiSetLbsClearAssistance(const SWI_STRUCT_PDSM_CLEAR_ASSISTANCE *psPdsmClearAssistance, SWI_U32 timeout);






#ifdef __cplusplus
}
#endif

#endif // __SWIMACPDSM_H__
