/*
 *  swiwimaxddf.h
 *  swimac
 *
 *  Created by Mark de Jong on 12/10/09.
 *  Copyright 2009 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWI_WIMAX_DDF_H
#define __SWI_WIMAX_DDF_H

#include "swiwimax.h"
#include "swimacstructs.h"
#include "swimacrcodes.h"

#ifdef __cplusplus
extern "C"	{
#endif

#pragma mark -
#pragma mark Constants / Defines
	// ********************************************************************************
	// Constants / Defines
	// ********************************************************************************

#define SWI_MAX_4G_SUBSCRIPTION_PROFILES		6		// Maximum number of 4G subscription profile
#define SWI_MAX_4G_LEN							125		// Maximum length of 4G realm/Username/Password
#define SWI_MAX_4G_NET_PARMS_OPERATOR_NAME		120		// Maximum length of 4G net parameter operator name
#define SWI_MAX_4G_NET_PARMS_GEN_OPERATOR_NAME	70		// Maximum length of 4G net parameter GEN operator name
#define SWI_MAX_4G_EAP_SERVER_REALMS_PER_EAP	2
#define SWI_MAX_4G_EAP_SERVER_REALM_LEN			62
#define SWI_MAX_4G_EAP_CERTS					4
#define SWI_MAX_4G_EAP_CERT_TYPE				20
#define SWI_MAX_4G_NET_PARMS					3
#define SWI_MAX_4G_NET_PARMS_CAPL				SWI_MAX_4G_NET_PARMS
#define SWI_MAX_4G_NET_PARMS_RAPL				SWI_MAX_4G_NET_PARMS
#define SWI_MAX_4G_NET_PARMS_CAPL_CHPLAN		20
#define SWI_4G_114BIT_FIELD						16
#define SWI_MAX_4G_NET_PARMS_H_NSP				13
#define SWI_MAX_4G_CAPL_REFID_LEN				5+1		// Extra byte for NULL terminator

#pragma mark -
#pragma mark Data structures
	// ********************************************************************************
	// Data structures
	// ********************************************************************************

	// SWI_4G_TYPE is used to contain user_id, pseudo_id, passwork, realm, and server_realm information
	typedef struct SWI_4G_TYPE
	{
		SWI_U16	index;
		SWI_U16	length;
		SWI_U8	string[SWI_MAX_4G_LEN];
	} SWI_4G_TYPE;
	
	// SwiWimaxSubscriptionParameters reflects the subscription branch of the DDF in the DM treet
	// Refer to DM documentation for details on what these fields mean
	typedef struct SwiWimaxSubscriptionParameters
	{
		SWI_U16	name_length; 
		SWI_U8	name[SWI_MAX_4G_NET_PARMS_OPERATOR_NAME];
		SWI_U16	activated;	// Boolean value
		SWI_U16	eap_entry_count;
		SWI_U16	active_eap;
		
		struct EAP_ENTRY
		{
			SWI_U16	index;
			SWI_U32	auth_method;	// METHOD_TYPE; see SWI_TYPE_4G_AUTH_METHOD for valid values;
			SWI_U32	vendor_id;
			SWI_U32	vendor_type;

			SWI_4G_TYPE	user_id;
			SWI_4G_TYPE	pseudo_id;
			SWI_4G_TYPE	password;
			SWI_4G_TYPE	realm;

			SWI_U16	use_privacy;	// Boolean value

			SWI_U16	valid_encaps;	// Boolean
			SWI_U32	encaps;

			SWI_U16	verify_server_realm;
			SWI_4G_TYPE	server_realm;

			SWI_U16	use_checkcode;		// Boolean value
			
			struct EAP_CERT
			{
				SWI_U16	index;
				struct EAP_CERT_INFO
				{
					SWI_U16	length;
					SWI_U8	cert_type[SWI_MAX_4G_EAP_CERT_TYPE];
					SWI_U16	valid_serial_number;
					SWI_U32	serial_number;
					SWI_U16	valid_thumbprint;
					SWI_U32	thumbprint;
				} eap_cert_info[SWI_MAX_4G_EAP_CERTS];
			} eap_cert;
		} eap_entry[SWI_MAX_4G_SUBSCRIPTION_PROFILES];
	} SwiWimaxSubscriptionParameters;
	
	// SwiWimaxNetworkParameters reflects the network branch of the DDF in the DM treet
	// Refer to DM documentation for details on what these fields mean
	typedef struct SwiWimaxNetworkParameters
	{
		SWI_U16	h_nsp_id_count;
		SWI_U32	h_nsp_id[SWI_MAX_4G_NET_PARMS_H_NSP];	
		SWI_U16	operator_length;
		SWI_U8	operator_name[SWI_MAX_4G_NET_PARMS_GEN_OPERATOR_NAME];
		SWI_U32	pollingInterval;
		
		struct CAPL
		{
			SWI_U16	capl_entry_count;
			SWI_U32	any;
			
			struct CAPL_ENTRY
			{
				SWI_U8	index;
				SWI_U32	nap_id;
				SWI_U32	priority;
				SWI_U32	chplan_ref_id_count;
				struct CHPLAN_REF_ID
				{
					SWI_U8	ref_id[SWI_MAX_4G_CAPL_REFID_LEN];
				} chplan_ref_ids[SWI_MAX_4G_NET_PARMS_CAPL_CHPLAN];
			} capl_entry[SWI_MAX_4G_NET_PARMS_CAPL];
		} capl;
		
		struct RAPL
		{
			SWI_U16	rapl_entry_count;
			SWI_U32	any;
			
			struct RAPL_ENTRY
			{
				SWI_U32	v_nsp_id;
				SWI_U32	priority;
			} rapl_entry[SWI_MAX_4G_NET_PARMS_RAPL];
		} rapl;
		
		struct CHPLAN
		{
			SWI_U32	bw;
			SWI_U32	fft_size;
			SWI_U32	duplex_mode;
			SWI_U16	chplan_entry_count;
			
			struct CHPLAN_ENTRY
			{
				SWI_U16	index;
				SWI_U8	id[SWI_MAX_4G_CAPL_REFID_LEN];
				SWI_U32	first_freq;
				SWI_U32	last_freq;
				SWI_U32	next_freq_step;
				SWI_U8	preambles[SWI_4G_114BIT_FIELD];
				SWI_U32	bw;
				SWI_U32	fft_size;
				SWI_U32	duplex_mode;
			} chplan_entry[SWI_MAX_4G_NET_PARMS_CAPL_CHPLAN];
		} chplan;
	} SwiWimaxNetworkParameters;
	
#pragma mark -
#pragma mark Function Declarations
	// ********************************************************************************
	// Function Declarations
	// ********************************************************************************
	
	/* ********************************************************************************
	 * Function:	SwiGetWimaxSubscriptionParameters
	 *
	 * Arguments:	parameters [OUT]	Structure containing all subscription paramters
	 *				timeout [IN]		Function timeout in milliseconds
	 *
	 * Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 * Discussion:	Returns all subscription parameters related to this Wimax device
	 */
	SWI_RCODE SwiGetWimaxSubscriptionParameters( SwiWimaxSubscriptionParameters *parameters, SWI_U32 timeout );

	/* ********************************************************************************
	 * Function:	SwiSetWimaxSubscriptionParameters
	 *
	 * Arguments:	parameters [IN]	Structure containing subscription paramters to set
	 *								in the device.
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 * Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 * Discussion:	Sets the subscription parameters for this Wimax device. Before
	 *				calling this function, be sure to call
	 *				SwiSetWimaxSubscriptionParameters and then change the fields that
	 *				should be changed.
	 *
	 * WARNING:		Do not make this call unless you know what you are doing. This can
	 *				completely corrupt the PRI information in the device, rendering it
	 *				non-functional.
	 */
	SWI_RCODE SwiSetWimaxSubscriptionParameters( SwiWimaxSubscriptionParameters *parameters, SWI_U32 timeout );

	/* ********************************************************************************
	 * Function:	SwiGetWimaxNetworkParameters
	 *
	 * Arguments:	parameters [OUT]	Structure containing all network paramters
	 *				timeout [IN]		Function timeout in milliseconds
	 *
	 * Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 * Discussion:	Returns all network parameters related to this Wimax device
	 */
	SWI_RCODE SwiGetWimaxNetworkParameters( SwiWimaxNetworkParameters *parameters, SWI_U32 timeout );
	
	/* ********************************************************************************
	 * Function:	SwiSetWimaxNetworkParameters
	 *
	 * Arguments:	parameters [IN]	Structure containing network paramters to set
	 *								in the device.
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 * Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 * Discussion:	Sets the network parameters for this Wimax device. Before
	 *				calling this function, be sure to call
	 *				SwiGetWimaxNetworkParameters and then change the fields that
	 *				should be changed.
	 *
	 * WARNING:		Do not make this call unless you know what you are doing. This can
	 *				completely corrupt the PRI information in the device, rendering it
	 *				non-functional.
	 */
	SWI_RCODE SwiSetWimaxNetworkParameters( SwiWimaxNetworkParameters *parameters, SWI_U32 timeout );
	
#ifdef __cplusplus
}
#endif

#endif // __SWI_WIMAX_DDF_H